"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResponseError = exports.RequestMethod = void 0;
exports.request = request;
const node_fetch_1 = __importDefault(require("node-fetch"));
var RequestMethod;
(function (RequestMethod) {
    RequestMethod["POST"] = "POST";
})(RequestMethod || (exports.RequestMethod = RequestMethod = {}));
class ResponseError extends Error {
    constructor(message, status, errors) {
        super(message);
        this.status = status;
        this.errors = errors;
    }
}
exports.ResponseError = ResponseError;
/**
 * Makes a request.
 *
 * @param url - Request endpoint.
 * @param body - Request body.
 * @param options - Request options.
 * @returns - Response.
 */
async function request(url, body, options) {
    const response = await (0, node_fetch_1.default)(url, {
        body: body ? JSON.stringify(body) : undefined,
        ...options,
    });
    const data = await response.json();
    if (response.ok) {
        return data;
    }
    throw new ResponseError(data.message, response.status, data.errors);
}
//# sourceMappingURL=request.js.map